######################## Statistical analysis and figures ###############################
# This file is the main data handling file for the study. It includes data 
# import and tidying of NTA data, exploritory data analysis of NTA data, and
# generation of all figures and calculation of p-values for protein MS data.


# Section 1 - Packages and other dependencies -----------------------------------------------------------------------------------
### Install and initiate packages ###
if (!require("tidyverse")) install.packages("tidyverse")
if (!require("scales")) install.packages("scales")
if (!require("ggpubr")) install.packages("ggpubr")
if (!require("ggsignif")) install.packages("ggsignif")
if (!require("png")) install.packages("png")
if (!require("cowplot")) install.packages("cowplot")
if (!require("magick")) install.packages("magick")
if (!require("gridExtra")) install.packages("gridExtra")
if (!require("grid")) install.packages("grid")
if (!require("car")) install.packages("car")
if (!require("VennDiagram")) install.packages("VennDiagram")
if (!require("RColorBrewer")) install.packages("RColorBrewer")
if (!require("gtools")) install.packages("gtools")
if (!require("matrixStats")) install.packages("matrixStats")


# Section 2 - Data analysis -----------------------------------------------------------------------------------
################## 2.1 - EV identification (Figure 2) #################### 
# Data concerning NTA measurements, such as particle size and concentration.


### Summary statistics ### 
# NTA_concentration
NTAdata %>% 
  group_by(method) %>% 
  summarize(mean = mean(NTA_concentration),
            sum = sum(NTA_concentration),
            sd = sd(NTA_concentration))
# NTA_mode
NTAdata %>% 
  group_by(method) %>% 
  summarize(mean = mean(NTA_mode),
            sum = sum(NTA_mode),
            sd = sd(NTA_mode))


###  Figure 2A - NTA concentration ###
# Error bars
errorBars2a <- NTAdata %>%
  group_by(method) %>%
  summarise(
    sd = sd(NTA_concentration),
    NTA_concentration = mean(NTA_concentration))

# Graph
figure_2a <- NTAdata %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = NTA_concentration)) +
  geom_jitter(aes(shape = method, size = 10), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 4) +
  geom_errorbar(aes(ymin = NTA_concentration-sd, ymax = NTA_concentration+sd), data = errorBars2a, width = 0.5) + 
  labs(title = "Particle concentration", y ="Particles/mL", x = "") +
  scale_y_continuous(labels = scientific, breaks = c(0, 2.5e11, 6.5e11, 1e12, 1.3e12), limits = c(0,1.4e12)) +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2,0,-3,1), "cm"), legend.position = "none", plot.title = element_text(size=50))
figure_2a


# clean up
rm(errorBars2a)

### Figure 2B - NTA_Mode size ###
# Comparison lines
errorBars2b <- NTAdata %>%
  group_by(method) %>%
  summarise(
    sd = sd(NTA_mode),
    NTA_mode = mean(NTA_mode))

# Graph
figure_2b <- NTAdata %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = NTA_mode)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = NTA_mode-sd, ymax = NTA_mode+sd), data = errorBars2b, width = 0.5) + 
  labs(title = "Mode Size", y ="Mode size (nm)", x = "") +
  scale_y_continuous(limits = c(0,185)) +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2,0,-3,1), "cm"), legend.position = "none", plot.title = element_text(size=50))

# Cleaup
rm(errorBars2b)

### Figure 2C - CD9 WB ### 
# Raw WB images are edited in WB_processing.R
figure_2c <- image_read("Figures/1 - Optimization study (2016)/Edited/Western blot/CD9_WB.png")
figure_2c <- image_border(figure_2c, "white", "30x20")

figure_2c <- rasterGrob(figure_2c)


### Figure 2D -  and TEM ###
# Read image (see image_editing.R to see editing process frow RAW)
figure_2d <- image_read("Figures/1 - Optimization study (2016)/Edited/TEM/Combined/combined.png")
figure_2d <- rasterGrob(figure_2d)


### Figure 2 - combined ###
figure_2 <- plot_grid(figure_2a, figure_2b, figure_2c, labels = "AUTO", ncol = 3, label_size = 70, rel_widths = c(2,2,3), rel_heights = c(2,2,2)) %>%
  plot_grid(figure_2d, labels = c('', 'D'), label_size = 70, ncol = 1)

ggsave(figure_2, filename = "Figures/1 - Optimization study (2016)/Publication/figure_2.png", width = 90, height = 45, units = "cm")

# Cleanup
rm(figure_2a,figure_2b, figure_2c,figure_2d,figure_2)


################################ 2.2 - Proteome differences (Figure 3) #################################### 
# Data concerning differences in protein IDs and isolation method grouping


### Figure 3A -  Venn diagram  ###
venn_all_df <- "Data/1 - Optimization study (2016)/Perseus export/Venn-diagrams/Protein-overlap.txt"
venn <- vennDiagramMatrix(venn_all_df)
venn

figure3a <- draw.triple.venn(area1 = venn[[1]], area2 =  venn[[2]], area3 = venn[[3]], n12= venn[[4]], n23 = venn[[5]], n13 = venn[[6]], n123 = venn[[7]],
                             category = c("  Centrifugation" , "SEC" , "PAP"),
                             
                             # Circles
                             lwd = 2,
                             lty = 'blank',
                             fill = myCol,
                             
                             # Numbers
                             cex = 1.6,
                             fontface = "bold",
                             fontfamily = "sans",
                             
                             # Set names
                             cat.cex = 1.6,
                             cat.fontface = "bold",
                             cat.default.pos = "outer",
                             cat.pos = c(-27, 27, 135),
                             cat.dist = c(0.055, 0.055, 0.085),
                             cat.fontfamily = "sans",
                             rotation = 1,
                             
                             # margin
                             margin = 0.05,
                             
                             
                             # Save
                             filename = "#figure_3a.png",
                             output = T)

ggsave2(figure3a, filename = "Figures/1 - Optimization study (2016)/Edited/figure_3a.png", width = 8, height = 8)

figure_3a <- image_read("Figures/1 - Optimization study (2016)/Edited/figure_3a.png")
figure_3a <- rasterGrob(figure_3a)


### Figure 3B - Clustering ###
figure_3b <- image_read("Figures/1 - Optimization study (2016)/Raw/Figure-3B (Clustering).png")
figure_3b <- image_crop(figure_3b, "1700x2396+150")
figure_3b <- image_border(figure_3b, "white", "0x30x")

figure_3b <- rasterGrob(figure_3b)

### Figure 3 - Combined ###
figure_3 <- plot_grid(figure_3a, figure_3b,labels = "AUTO", nrow= 1, ncol = 2, align = "l", label_size = 50, rel_heights = c(1,2,3,4), hjust = c(-0.5, 0.5))


save_plot(figure_3, filename = "Figures/1 - Optimization study (2016)/Publication/figure_3.png", ncol = 6, nrow = 3, base_aspect_ratio = 1)

# Cleanup
rm(figure_3a,figure_3b, figure3a,figure_3)



################################ 2.3 - Quantitative proteome differences (Figure 4) #################################### 
# Data that calculates the mail quantitative differences between the different isolation
# methods in relation to protein (riBAQ) values).


### Data file ### 
totEV_df <- "Data/1 - Optimization study (2016)/Perseus export/T-tests/Total-EVs.txt"
largeEV_df <- "Data/1 - Optimization study (2016)/Perseus export/T-tests/Large-EVs.txt"
smallEV_df <- "Data/1 - Optimization study (2016)/Perseus export/T-tests/Small-EVs.txt"

### Fold change + summary statistics ### 
fold_change(totEV_df)
fold_change(largeEV_df)
fold_change(smallEV_df)


### Statistical inference ###
ms_inference(totEV_df)
ms_inference(largeEV_df)
ms_inference(smallEV_df)


### Figure 4A -  Total EVs ###
## Error bars
errorBars4a <- errorBar(totEV_df)

## Graph
figure_4a <-readMS(totEV_df) %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = riBAQ)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = riBAQ-sd, ymax = riBAQ+sd), data = errorBars4a, width = 0.5) + 
  labs(title = "EV abundance", y ="riBAQ", x = "") +
  geom_signif(comparisons = sig_lines(totEV_df), step_increase = 0.1, annotations = sig_test(totEV_df), size = 1.5, textsize = 12, vjust = 0.5) +
  scale_y_continuous() +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))
figure_4a

### Figure 4b -  Venn diagram EVs ###
file <- "Data/1 - Optimization study (2016)/Perseus export/Venn-diagrams/EV-overlap.txt"
venn <- vennDiagramMatrix(file)

figure_4b <- draw.triple.venn(area1 = venn[[1]], area2 =  venn[[2]], area3 = venn[[3]], n12= venn[[4]], n23 = venn[[5]], n13 = venn[[6]], n123 = venn[[7]],
                              category = c("Centrifugation" , "SEC" , "PAP"),
                              
                              # Circles
                              lwd = 2,
                              lty = 'blank',
                              fill = myCol,
                              
                              # Numbers
                              cex = 4,
                              fontface = "bold",
                              fontfamily = "sans",
                              
                              # Set names
                              cat.cex = 6,
                              cat.pos = c(-27, 27, 135),
                              cat.dist = c(0.055, 0.055, 0.085),
                              cat.fontfamily = "sans",
                              rotation = 1,
                              
                              
                              # margin
                              margin = 0.05,
                              scaled = F,
                              euler.d = F,
                              height = 1,
                              width = 1)

ggsave2(figure_4b, filename = "Figures/1 - Optimization study (2016)/Edited/figure_4b.png", scale = 2.5, width = 8, height = 8)
figure_4b <- image_read("Figures/1 - Optimization study (2016)/Edited/figure_4b.png")
figure_4b <- rasterGrob(figure_4b)



### Figure 4c -  Large EVs ###
## Error bar
errorBars4c <- errorBar(largeEV_df)


## Graph
figure_4c <- readMS(largeEV_df) %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = riBAQ)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = riBAQ-sd, ymax = riBAQ+sd), data = errorBars4c, width = 0.5) + 
  labs(title = "Large EVs", y ="riBAQ", x = "") +
  geom_signif(comparisons = sig_lines(largeEV_df), step_increase = 0.1, annotations = sig_test(largeEV_df), size = 1.5, textsize = 12, vjust = 0.5) +
  scale_y_continuous() +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))

### Figure 4d -  Small EVs ### 
## Error bar 
errorBars4d <- errorBar(smallEV_df)

## Graph
figure_4d <- readMS(smallEV_df) %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = riBAQ)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = riBAQ-sd, ymax = riBAQ+sd), data = errorBars4d, width = 0.5) + 
  labs(title = "Small EVs", y ="riBAQ", x = "") +
  geom_signif(comparisons = sig_lines(smallEV_df), step_increase = 0.1, annotations = sig_test(smallEV_df), size = 1.5, textsize = 12, vjust = 0.5) +
  scale_y_continuous(labels = scientific, breaks = c(0, 1e-4, 2e-4, 3e-4, 4e-4, 5e-4, 6e-4)) +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))

### Figure 4 - Combined ###
## Arrange in grid
figure_4 <- plot_grid(figure_4a, figure_4b, figure_4c, figure_4d, labels = "AUTO", ncol = 2, label_size = 70)

ggsave(figure_4, filename = "Figures/1 - Optimization study (2016)/Publication/figure_4.png", width = 70, height = 50, units = "cm")

# Cleanup
rm(figure_4a,figure_4b,figure_4, figure_4d, figure_4c,errorBars4a,errorBars4d)



################################ 2.4 - Contaminants (Figure 5) #################################### 
# Data concerning differences in contaminants

### Data file ### 
alb_df <- "Data/1 - Optimization study (2016)/Perseus export/T-tests/Albumin.txt"
lip_df <- "Data/1 - Optimization study (2016)/Perseus export/T-tests/Lipoproteins.txt"
nonEV_df <- "Data/1 - Optimization study (2016)/Perseus export/T-tests/Non-EVs.txt"

### Fold change + summary statistics ### 
fold_change(alb_df)
fold_change(lip_df)
fold_change(nonEV_df)


### Statistical inference ###
ms_inference(alb_df)
ms_inference(lip_df)
ms_inference(nonEV_df)

### Figure 5a -  Albumin ###
# Error bars
errorBars5a <- errorBar(alb_df)

## Graph
figure_5a <- readMS(alb_df) %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = riBAQ)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = riBAQ-sd, ymax = riBAQ+sd), data = errorBars5a, width = 0.5) + 
  labs(title = "Serum Albumin", y ="riBAQ", x = "") +
  geom_signif(comparisons = sig_lines(alb_df), step_increase = 0.1, annotations = sig_test(alb_df), size = 1.5, textsize = 12, vjust = 0.5) +
  scale_y_continuous(breaks = c(0.02, 0.04, 0.06,0.08,0.10)) +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))


### Figure 5b - Lipoproteins ###
# Error bars
errorBars5b <- errorBar(lip_df)

## Graph
figure_5b <- readMS(lip_df) %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = riBAQ)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = riBAQ-sd, ymax = riBAQ+sd), data = errorBars5b, width = 0.5) + 
  labs(title = "Lipoproteins", y ="riBAQ", x = "") +
  geom_signif(comparisons = sig_lines(lip_df), step_increase = 0.1, annotations = sig_test(lip_df), size = 1.5, textsize = 12, vjust = 0.5) +
  scale_y_continuous() +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))

### Figure 5c -  WB ###
## Import images
figure_5c <- image_read("Figures/1 - Optimization study (2016)/Edited/Western blot/apoB_WB.png")
figure_5c <- image_border(figure_5c, "white", "0x30x")

figure_5c <- rasterGrob(figure_5c)

### Figure 5d -  Non-EV ###
## Error bars
errorBars5d <- errorBar(nonEV_df)

## Graph
figure_5d <- readMS(nonEV_df) %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = riBAQ)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  geom_point(stat="summary", fun="mean", size = 3) +
  geom_errorbar(aes(ymin = riBAQ-sd, ymax = riBAQ+sd), data = errorBars5d, width = 0.5) + 
  labs(title = "Non-EV proteins", y ="riBAQ", x = "") +
  geom_signif(comparisons = sig_lines(nonEV_df), step_increase = 0.1, annotations = sig_test(nonEV_df), size = 1.5, textsize = 12, vjust = 0.5) +
  scale_y_continuous(breaks = c(0.00, 0.02, 0.04, 0.06, 0.08)) +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))



### Figure 5 - Combined ###
figure_5 <- plot_grid(figure_5a, figure_5b, figure_5c, figure_5d,
    labels = "AUTO", ncol = 2, label_size = 70)

ggsave(figure_5, filename = "Figures/1 - Optimization study (2016)/Publication/figure_5.png", width = 70, height = 50, units = "cm")

# cleanup
rm(figure_5a,figure_5b,figure_5, figure_5d, figure_5c, errorBars5a,errorBars5b,errorBars5d)



################################ 2.5 - Reproducibility (Figure 6) #################################### 
# Data concerning reproducibility of EV isolation methods in relation to both
# protein identificaitons (fig 6a), and protein abundance (fig 6b+c).


### Figure 6a -  Repeatability ###
# data
rep <- "Data/1 - Optimization study (2016)/Perseus export/Repeatability/Repeatability.txt"

repeatabiliy <-  repeatability(rep)

# new names
repeatabiliy[1] <- c("Cent.", "Cent.", "Cent.", "SEC", "SEC", "SEC", "PAP", "PAP", "PAP")

# Summary
repeatabiliy %>%
  group_by(method) %>%
  summarise(mean = mean(Percentage), sd = sd(Percentage), min = min(Percentage), max = max(Percentage)) 

## Graph
figure_6a <- repeatabiliy %>%
  ggplot(aes(x = factor(method, levels=c("Cent.", "SEC", "PAP")), y = Percentage)) +
  geom_jitter(aes(shape = method, size = 25), width = 0.1,colour = "grey") +
  labs(title = paste("Repeatability of \nprotein identification"), y ="Percentage", x = "") +
  scale_y_continuous(labels = function(x) paste0(x, "%"), breaks = c(0, 20, 40, 60, 80, 100), limits = c(0, 100)) +
  theme_pubr(x.text.angle = 45, base_size = 35) +
  theme(plot.margin= unit(c(2.5,0.5,0.5,0.5,0.5), "cm"), legend.position = "none", plot.title = element_text(size=50))

### Figure 6b -  correlation matrix ###
figure_6b <- image_read("Figures/1 - Optimization study (2016)/Raw/figure-6B (R Squared).png")
figure_6b <- image_border(figure_6b, "white", "0x50")
figure_6b <- rasterGrob(figure_6b)

### Figure 6c - correlation matrix for total EVs.
figure_6c <- image_read("Figures/1 - Optimization study (2016)/Raw/Figure-6C (R squared).png")
figure_6c <- image_border(figure_6c, "white", "0x50")
figure_6c <- rasterGrob(figure_6c)

### Figure 6 - Combined ###
figure_6 <- plot_grid(figure_6a, figure_6b,
                      labels = "AUTO", ncol = 2, label_size = 70, rel_widths = c(1, 2), hjust = c(-0.5, -3)) %>%
plot_grid(figure_6c,labels = c("","C"), ncol = 1, label_size = 70, hjust = -9.5)                      


ggsave(figure_6, filename = "Figures/1 - Optimization study (2016)/Publication/figure_6.png", width = 80, height = 50, units = "cm")

# cleanup
rm(figure_6a,figure_6b,figure_6)


